pub struct TelemetryMetrics {Show 15 fields
pub cache_hits: u64,
pub cache_misses: u64,
pub cache_hit_rate: f64,
pub cache_size: usize,
pub cache_capacity: usize,
pub cache_evictions: u64,
pub pool_size: usize,
pub idle_connections: usize,
pub active_connections: usize,
pub is_closed: bool,
pub db_queries_total: u64,
pub db_query_errors: u64,
pub register_single_calls: u64,
pub register_batch_calls: u64,
pub total_objects_registered: u64,
}Expand description
A snapshot of all telemetry metrics.
This struct provides a complete view of the register’s performance and is designed to work well with OpenTelemetry exporters.
Fields
cache_hits: u64cache_misses: u64cache_hit_rate: f64cache_size: usizecache_capacity: usizecache_evictions: u64pool_size: usizeidle_connections: usizeactive_connections: usizeis_closed: booldb_queries_total: u64db_query_errors: u64register_single_calls: u64register_batch_calls: u64total_objects_registered: u64Trait Implementations
Sourceimpl Clone for TelemetryMetrics
impl Clone for TelemetryMetrics
Sourcefn clone(&self) -> TelemetryMetrics
fn clone(&self) -> TelemetryMetrics
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for TelemetryMetrics
impl RefUnwindSafe for TelemetryMetrics
impl Send for TelemetryMetrics
impl Sync for TelemetryMetrics
impl Unpin for TelemetryMetrics
impl UnwindSafe for TelemetryMetrics